@@ -3,7 +3,7 @@
 /* package name */
 #define PACKAGE "pianobar"
 
-#define VERSION "2020.04.05"
+#define VERSION "2020.11.28"
 
 /* glibc feature test macros, define _before_ including other files */
 #define _POSIX_C_SOURCE 200809L
@@ -42,3 +42,10 @@
 #define HAVE_AV_REGISTER_ALL
 #endif
 
+#ifndef NDEBUG
+#define HAVE_DEBUGLOG
+#define debug(...) fprintf(stderr, __VA_ARGS__)
+#else
+#define debug(...)
+#endif
+
