@@ -21,10 +21,8 @@ OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 THE SOFTWARE.
 */
 
-#ifndef SRC_TERMINAL_H_WY8F3MNH
-#define SRC_TERMINAL_H_WY8F3MNH
+#pragma once
 
 void BarTermInit ();
 void BarTermRestore ();
 
-#endif /* SRC_TERMINAL_H_WY8F3MNH */
